# Binalyzer WebAssembly Extension

This repository provides the WebAssembly extension for [Binalyzer]. It implements
value providers (e.g. for LEB128) that are used to parse WebAssembly's
binary module format. It is part of the overall [Binalyzer] project and comes with
its installation.

[Binalyzer]: https://github.com/denisvasilik/binalyzer

## Installation

Binalyzer is published on [PyPI] and can be installed from there:

```sh
~$ pip3 install --upgrade binalyzer
```

If you wish to install [Binalyzer] for development purposes, refer to [the
developer's guide].

[PyPI]: https://pypi.org/project/Binalyzer/
[Binalyzer]: https://pypi.org/project/Binalyzer/
[the developer's guide]: DEVELOPMENT.md

## Documentation

Documentation is available from [binalyzer.readthedocs.io].

[binalyzer.readthedocs.io]: https://binalyzer.readthedocs.io/en/latest/

## Get in touch

- Report bugs, suggest features or view the source code [on GitHub].
- For contributions refer to [the contributor's guide].

[on GitHub]: https://github.com/denisvasilik/binalyzer
[the contributor's guide]: CONTRIBUTING.md

# License

Licensed under the MIT license ([LICENSE-MIT] or http://opensource.org/licenses/MIT).

[LICENSE-MIT]: LICENSE.rst